@@ -1,5 +1,5 @@
 package Schedule::LongSteps;
-$Schedule::LongSteps::VERSION = '0.007';
+$Schedule::LongSteps::VERSION = '0.008';
 # ABSTRACT: Manage long term processes over arbitrary large spans of time.
 
 use Moose;
@@ -105,7 +105,7 @@ Then in you main application do this once per 'target':
    my $longsteps = Schedule::LongSteps->new({ storage => $dbic_storage });
    ...
 
-   $longsteps->instanciate_process('My::Application::MyProcess', { thing => 'whatever' }, { the => 'init', state => 1 });
+   $longsteps->instantiate_process('My::Application::MyProcess', { thing => 'whatever' }, { the => 'init', state => 1 });
 
 Then regularly (in a cron, or a recurring callback):
 
@@ -123,7 +123,7 @@ example.
 
 =head1 PERSISTANCE
 
-The persistance of processes is managed by a subclass of L<Schedule::LongSteps::Storage> that you should instanciate
+The persistance of processes is managed by a subclass of L<Schedule::LongSteps::Storage> that you should instantiate
 and given to the constructor of L<Schedule::LongSteps>
 
 Example:
@@ -158,7 +158,7 @@ don't mind writing your own resultset.
 
 See 'QUICK START AND SYNOPSIS'
 
-=head2 INSTANCIATING A NEW PROCESS
+=head2 INSTANTIATING A NEW PROCESS
 
 See 'QUICK START AND SYNOPSIS'
 
@@ -171,7 +171,7 @@ See 'QUICK START AND SYNOPSIS
 Of course each instance of your process will most probably need to
 act on different pieces of application data. The one and only way to
 give 'parameters' to your processes is to specify an initial state when
-you instanciate a process:
+you instantiate a process:
 
   $longsteps->instantiate_process('My::App', { app => $app } , { work => 'on' , this => 'user_id' });
 
@@ -187,7 +187,7 @@ And you want to use it in your processes:
   ...
   has 'app' => (is => 'ro', isa => 'My::App', required => 1);
 
-You can inject your $app instance in your processes at instanciation time:
+You can inject your $app instance in your processes at instantiation time:
 
   $longsteps->instantiate_process('My::App', { app => $app });
 
@@ -244,8 +244,8 @@ Simply do in your step 'do_last_stuff' implementation:
 
   sub do_fork{
      ...
-     my $p1 = $self->longsteps->instanciate_process('AnotherProcessClass', \%build_args , \%initial_state );
-     my $p2 = $self->longsteps->instanciate_process('YetAnotherProcessClass', \%build_args2 , \%initial_state2 );
+     my $p1 = $self->longsteps->instantiate_process('AnotherProcessClass', \%build_args , \%initial_state );
+     my $p2 = $self->longsteps->instantiate_process('YetAnotherProcessClass', \%build_args2 , \%initial_state2 );
      ...
      return $self->new_step({ what => 'do_join', run_at => DateTime->now() , { processes => [ $p1->id(), p2->id() ] } });
   }
@@ -284,7 +284,7 @@ Returns the number of processes run
 
 =head2 instantiate_process
 
-Instanciate a stored process from the given process class returns a new process that will have an ID.
+Instantiate a stored process from the given process class returns a new process that will have an ID.
 
 Usage:
 
@@ -334,13 +334,16 @@ sub run_due_processes{
     my $stored_processes = $self->storage->prepare_due_processes();
     my $process_count = 0;
     while( my $stored_process = $stored_processes->next() ){
-        Class::Load::load_class($stored_process->process_class());
-        my $process = $stored_process->process_class()->new({ longsteps => $self, stored_process => $stored_process, %{$context} });
         my $process_method = $stored_process->what();
 
         $process_count++;
 
-        my $new_step_properties = eval{ $process->$process_method(); };
+        my $new_step_properties = eval{
+            Class::Load::load_class($stored_process->process_class());
+            my $process = $stored_process->process_class()->new({ longsteps => $self, stored_process => $stored_process, %{$context} });
+
+            $process->$process_method();
+        };
         if( my $err = $@ ){
             $log->error("Error running process ".$stored_process->process_class().':'.$stored_process->id().' :'.$err);
             $stored_process->update({
