@@ -1,5 +1,5 @@
 package Schedule::LongSteps::Storage::Memory;
-$Schedule::LongSteps::Storage::Memory::VERSION = '0.007';
+$Schedule::LongSteps::Storage::Memory::VERSION = '0.008';
 use Moose;
 extends qw/Schedule::LongSteps::Storage/;
 
@@ -85,7 +85,7 @@ sub create_process{
 __PACKAGE__->meta->make_immutable();
 
 package Schedule::LongSteps::Storage::Memory::Process;
-$Schedule::LongSteps::Storage::Memory::Process::VERSION = '0.007';
+$Schedule::LongSteps::Storage::Memory::Process::VERSION = '0.008';
 use Moose;
 
 use DateTime;
@@ -93,7 +93,7 @@ use DateTime;
 my $IDSEQUENCE = 0;
 
 has 'id' => ( is => 'ro', isa => 'Int', default => sub{ ++$IDSEQUENCE ; } );
-has 'process_class' => ( is => 'ro', isa => 'Str', required => 1);
+has 'process_class' => ( is => 'rw', isa => 'Str', required => 1); # rw only for test. Should not changed ever.
 has 'status' => ( is => 'rw', isa => 'Str', default => 'pending' );
 has 'what' => ( is => 'rw' ,  isa => 'Str', required => 1);
 has 'run_at' => ( is => 'rw', isa => 'Maybe[DateTime]', default => sub{ undef; } );
